@@ -5,7 +5,7 @@ import requests
 import sys
 import shutil
 import re
-from tqdm import tqdm, trange
+from tqdm import tqdm
 import numpy as np
 import tensorflow as tf
 from tensorflow.core.protobuf import rewriter_config_pb2
